@@ -15,10 +15,15 @@
 import math
 from typing import NamedTuple, Optional, Union
 
-_DEFAULT_ALMOST_EQUAL_TOLERENCE = 1e-9
+
+_DEFAULT_ALMOST_EQUAL_TOLERANCE = 1e-9
 _PointOrVec = Union["Point", "Vector"]
 
 
+def almost_equal(c1, c2, tolerance=_DEFAULT_ALMOST_EQUAL_TOLERANCE) -> bool:
+    return abs(c1 - c2) <= tolerance
+
+
 class Point(NamedTuple):
     x: float = 0
     y: float = 0
@@ -51,9 +56,11 @@ class Point(NamedTuple):
         return Point(round(self.x, digits), round(self.y, digits))
 
     def almost_equals(
-        self, other: "Point", tolerence=_DEFAULT_ALMOST_EQUAL_TOLERENCE
+        self, other: "Point", tolerance=_DEFAULT_ALMOST_EQUAL_TOLERANCE
     ) -> bool:
-        return abs(self.x - other.x) <= tolerence and abs(self.y - other.y) <= tolerence
+        return almost_equal(self.x, other.x, tolerance) and almost_equal(
+            self.y, other.y, tolerance
+        )
 
 
 class Vector(NamedTuple):
@@ -112,3 +119,18 @@ class Rect(NamedTuple):
     def empty(self) -> bool:
         """Return True if the Rect's width or height is 0."""
         return self.w == 0 or self.h == 0
+
+    def intersection(self, other: "Rect") -> Optional["Rect"]:
+        def _overlap(start1, end1, start2, end2):
+            start = max(start1, start2)
+            end = min(end1, end2)
+            if start >= end:
+                return (0.0, 0.0)
+            return (start, end)
+
+        x1, x2 = _overlap(self.x, self.x + self.w, other.x, other.x + other.w)
+        y1, y2 = _overlap(self.y, self.y + self.h, other.y, other.y + other.h)
+
+        if x1 != x2 and y1 != y2:
+            return Rect(x1, y1, x2 - x1, y2 - y1)
+        return None
